@@ -2,7 +2,7 @@
 #
 # Prepare the stage...
 #
-# $Id: moby-s-install.pl,v 1.14 2008/11/25 19:47:23 kawas Exp $
+# $Id: moby-s-install.pl,v 1.15 2009/04/15 16:38:57 kawas Exp $
 # Contact: Edward Kawas <edward.kawas@gmail.com>
 # -----------------------------------------------------------
 
@@ -1480,6 +1480,12 @@ if ($answer eq 'y') {
 	    'MOBY-Central test page for auxillary scripts',
 	    { '#!/usr/bin/perl -w' => "#!$perl_exec", }
 	    );
+	file_from_template(
+	    "$apache_cgi/BioMobyWSDL",
+	    File::ShareDir::dist_file( 'MOBY', 'cgi/BioMobyWSDL' ),
+	    'MOBY-Central RESTful WSDL generator',
+	    { '#!/usr/bin/perl -w' => "#!$perl_exec", }
+	    );
 	file_from_template(
 	    "$apache_cgi/ServicePingerValidator",
 	    File::ShareDir::dist_file(
