@@ -100,7 +100,7 @@ use MOBY::Async::WSRF;
 use base qw(WSRF::FileBasedMobyResourceLifetimes);
 
 use vars qw /$VERSION/;
-$VERSION = sprintf "%d.%02d", q$Revision: 1.4 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.6 $ =~ /: (\d+)\.(\d+)/;
 
 #===============================================================================
 # async_create
@@ -122,6 +122,10 @@ my $async_create = sub {
         my($query)=CGI->new();
         my($proto)=($query->https())?'https':'http';
         my($host)=$query->virtual_host();
+	# This line is needed to fix a bug in CGI library
+	# which only appears when the server is living behind
+	# more than one proxy
+	$host =~ s/^([^,]+),.*/$1/;
         my($port)=$query->virtual_port();
 	if(($proto eq 'http' && $port eq '80') || ($proto eq 'https' && $port eq '443')) {
 		$port='';
@@ -180,9 +184,12 @@ my $async_submit = sub {
 	my $auth = $mobyContent->getAttribute('authority') || $mobyContent->getAttributeNS($WSRF::Constants::MOBY_MESSAGE_NS,'authority');
 	
 	# Get mobyData and iterate over them in order to run the service for each one
-	my @mobyData = ($moby->getElementsByTagNameNS($WSRF::Constants::MOBY_MESSAGE_NS,'mobyData'));
+	my @mobyData = ($mobyContent->getChildrenByTagNameNS($WSRF::Constants::MOBY_MESSAGE_NS,'mobyData'));
 
 	foreach my $mobyData (@mobyData) {
+		# This line avoids a serialization bug in XML::LibXML, which probably
+		# is inherited from libxml2
+		$mobyData->setNamespace($WSRF::Constants::MOBY_MESSAGE_NS, $mobyData->prefix(), 0);
 		my $queryID = $mobyData->getAttribute('queryID') || $mobyData->getAttributeNS($WSRF::Constants::MOBY_MESSAGE_NS,'queryID');
 		my $property_pid    = "pid_$queryID";
 		my $property_input  = "input_$queryID";
